@@ -39,7 +39,7 @@ class Uncertainty:
         self._var_name = var_name
         self._sli = tuple([slice(None)] * self._obj[self._unc_var_name].ndim)
         if sli is not None:
-            self._sli = self.expand_sli(sli)
+            self._sli = self._expand_sli(sli)
 
     def __str__(self):
         """Custom __str__"""
@@ -61,11 +61,11 @@ class Uncertainty:
         """
 
         # update slice
-        self._sli = self.expand_sli(sli)
+        self._sli = self._expand_sli(sli)
 
         return self
 
-    def expand_sli(self, sli: Optional[tuple] = None) -> tuple:
+    def _expand_sli(self, sli: Optional[tuple] = None) -> tuple:
         """
         Function to expand the provided sli so that it always has the right number of dimensions
 
@@ -79,16 +79,12 @@ class Uncertainty:
         if sli is None:
             out_sli = tuple([slice(None)] * self._obj[self._unc_var_name].ndim)
 
-        # # if the sli tuple has the correct shape, it can be used directly
-        # elif self._obj[self._unc_var_name].ndim == len(sli):
-        #     out_sli = sli
-
-        # If different shape, set each dimension to slice(None) and then change the
-        # ones provided in the new slice. E.g. if providing [0] for a variable with
-        # 3 dimensions, this becomes [0,slice(None),slice(None)]
+        # Otherwise, set each : dimension to slice(None)
+        # E.g. if providing [0] for a variable with 3 dimensions, this becomes
+        # [0,slice(None),slice(None)]
         else:
             out_sli = list([slice(None)] * self._obj[self._unc_var_name].ndim)
-            sli_list = list(sli)
+            sli_list = list(sli) if isinstance(sli, tuple) else [sli]
             for i in range(len(sli_list)):
                 if not sli_list[i] == ":":
                     out_sli[i] = sli_list[i]
@@ -96,6 +92,20 @@ class Uncertainty:
 
         return out_sli
 
+    def rename(self, name) -> xr.Dataset:
+        """
+        Renames uncertainty variable and safely updates variable name references in obs variable metadata
+        :param name: desired name
+        :returns: dataset with safely renamed variable
+        """
+        self._obj = self._obj.rename({self._unc_var_name: name})
+        self._obj[self._var_name].attrs["unc_comps"] = [
+            v.replace(self._unc_var_name, name)
+            for v in self._obj[self._var_name].attrs["unc_comps"]
+        ]
+
+        return self._obj
+
     @property
     def err_corr(self) -> List[Tuple[Union[str, List[str]], BaseErrCorrForm]]:
         """
@@ -109,7 +119,9 @@ class Uncertainty:
         # Find dimensions in variable slice
         sli_dims = [
             dim
-            for dim, idx in zip(self._obj.dims.keys(), self._sli)
+            for dim, idx in zip(
+                self._obj.dims.keys(), self._sli
+            )  # Due to hit a FutureDeprecation warning
             if not isinstance(idx, int)
         ]
 
@@ -309,22 +321,6 @@ class Uncertainty:
                     )
         return err_corr_dict
 
-    def err_corr_dict_numdim(self) -> dict:
-        """
-        Error-correlation dictionary for uncertainty effect, where the keys are the dimension index rather than dimension name.
-
-        :return: dictionary with error-correlation for each dimension
-        """
-        # initialise error-correlation dictionary
-        err_corr_dict = self.err_corr_dict()
-        err_corr_dict_numdim = {}
-
-        for idim, dim in enumerate(self._obj.dims):
-            if dim in err_corr_dict.keys():
-                err_corr_dict_numdim[str(idim)] = err_corr_dict[dim]
-
-        return err_corr_dict_numdim
-
     def err_corr_matrix(self) -> xr.DataArray:
         """
         Error-correlation matrix for uncertainty effect.
@@ -340,14 +336,10 @@ class Uncertainty:
         # populate with error-correlation matrices built be each error-correlation
         # parameterisation object
         for dim_err_corr in self.err_corr:
-            if np.all(
-                [
-                    dim in self._obj[self._unc_var_name][self._sli].dims
-                    for dim in dim_err_corr[1].dims
-                ]
-            ):
+            sliced_dims = dim_err_corr[1].get_sliced_dims_errcorr(self._sli)
+            if len(dim_err_corr[1].get_sliced_dims_errcorr(self._sli)) > 0:
                 err_corr_matrix.values = err_corr_matrix.values.dot(
-                    dim_err_corr[1].build_matrix(self._sli)
+                    dim_err_corr[1].build_dot_matrix(self._sli)
                 )
 
         return err_corr_matrix
@@ -526,7 +518,7 @@ class VariableUncertainty:
                 quadsum_unc += self[unc_var_name].abs_value ** 2.0
 
         if quadsum_unc is not None:
-            quadsum_unc = quadsum_unc ** 0.5
+            quadsum_unc = quadsum_unc**0.5
 
         return quadsum_unc
 
@@ -675,7 +667,12 @@ class UncAccessor(object):
         return str(self)
 
     def __getitem__(self, var_name: str) -> VariableUncertainty:
-        """Custom  __repr__"""
+        """
+        Returns :py:class:`~obsarray.unc_accessor.VariableUncertainty` object to interface with uncertainty information for a given observation variable
+
+        :param var_name: observation variable name
+        :return: observation variable uncertainty interface
+        """
         return VariableUncertainty(self._obj, var_name)
 
     def __len__(self):
@@ -711,7 +708,7 @@ class UncAccessor(object):
         else:
             raise StopIteration
 
-    def keys(self):
+    def keys(self) -> list:
         """
         Returns observation variable names
 
@@ -823,7 +820,6 @@ class UncAccessor(object):
         """
 
         unc_var_names = self._var_unc_var_names(obs_var_name, unc_type=unc_type)
-
         if len(unc_var_names) == 0:
             return None
 
